@@ -23,7 +23,7 @@ pub fn render(input: String) -> String {
 
 pub fn get_svg_icon(name: &str, size: usize, color: (u8, u8, u8)) -> Option<String> {
 
-    match markdown::icon::get_icon(&crate::utils::into_v16(name), size, Some(color)) {
+    match markdown::icon::get_icon(&crate::utils::into_v16(name), size, Some(color), true) {
         None => None,
         Some(v) => Some(String::from_utf16_lossy(&v))
     }
